@@ -1,3 +1,4 @@
+import os
 from shutil import copy2
 from strange_case.nodes import FileNode
 
@@ -7,7 +8,9 @@ class AssetNode(FileNode):
     Copies a file to a destination
     """
     def generate_file(self, site, source_path, target_path):
-        if not self['skip']:
+        if not os.path.exists(target_path) or not self['skip']:
             copy2(source_path, target_path)
+        elif self['verbose']:
+            print "Skipping %s" % target_path
         self.files_tracked.append(source_path)
         self.files_written.append(target_path)
